@@ -20,13 +20,10 @@ def get_nearest_index(tim_eq, tarr):
         unique_idx = [0]
         index_idx = {0: [0]}
     else:
-#        idx = np.argmin(np.abs(tim_eq[:, None] - tarr), axis=0)
         tarr = np.minimum(np.maximum(tarr, tim_eq[0]), tim_eq[-1])
-        idx = interp1d(tim_eq, np.arange(len(tim_eq)), kind='nearest')(tarr)
-        idx = np.atleast_1d(np.int_(idx))
-#        idx = np.searchsorted(tim_eq, tarr) # not closest, either left or right
+        idx = interp1d(tim_eq, np.arange(len(tim_eq)), kind='nearest', assume_sorted=True)(tarr)
+        idx = idx.astype(np.int32)
         unique_idx = np.unique(idx)
-        unique_idx = np.minimum(unique_idx, len(tim_eq) - 1)
         index_idx = {}
         for i in unique_idx:
             (index_idx[i], ) = np.where(idx == i)
