@@ -4,10 +4,10 @@ import sys
 import numpy as np
 
 try:
-    from aug_sfutils import sfobj, SFREAD
+    from . import sfobj, SFREAD, parse_kwargs
 except:
     from sfread import SFREAD
-    import sfobj
+    import sfobj, parse_kwargs
 
 
 class EMPTY:
@@ -42,20 +42,11 @@ class EQU:
             final time [s]
         """
 
-        ## Shotfile diag
-        if 'diag' in kwargs.keys():
-            diag = kwargs['diag']
-        elif 'diagnostic' in kwargs.keys():
-            diag = kwargs['diagnostic']
-        else:
-            diag = 'EQH'
-        if 'ed' in kwargs.keys():
-            ed = kwargs['ed']
-        elif 'edition' in kwargs.keys():
-            ed = kwargs['edition']
-        else:
-            ed = 0
-        self.sf = SFREAD(nshot, diag, ed=ed)
+        exp  = parse_kwargs.parse_kw( ('exp', 'experiment'), kwargs, default='AUGD')
+        diag = parse_kwargs.parse_kw( ('diag', 'diagnostic'), kwargs, default='EQH')
+        ed   = parse_kwargs.parse_kw( ('ed', 'edition'), kwargs, default=0)
+
+        self.sf = SFREAD(nshot, diag, ed=ed, exp=exp)
 
         if self.sf.status:
 
@@ -63,17 +54,12 @@ class EQU:
             self.shot = nshot 
 
             ## Shotfile exp
-            if 'exp' in kwargs.keys():
-                self.exp = kwargs['exp']
-            elif 'experiment' in kwargs.keys():
-                self.exp = kwargs['experiment']
-            else:
-                self.exp = 'AUGD'
+            self.exp = exp
             
             ## Shotfile diag
             self.diag = diag
 
-            ## Shotfile edition
+            ## Actual shotfile edition (> 0)
             self.ed = self.sf.ed
 
             ## COCOs number
