@@ -2,9 +2,9 @@ import os, datetime
 from struct import unpack
 import numpy as np
 try:
-    from . import sfdics, sfhread, sfobj, manage_ed
+    from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs
 except:
-    import sfdics, sfhread, sfobj, manage_ed
+    import sfdics, sfhread, sfobj, manage_ed, parse_kwargs
 
 verbose = True
 verbose = False
@@ -189,18 +189,8 @@ class SFREAD:
         if 'diag' not in locals():
             diag = input('Please enter a diag_name (str(3), no delimiter):\n')
 
-        if 'exp' in kwargs.keys():
-            exp = kwargs['exp']
-        elif 'experiment' in kwargs.keys():
-            exp = kwargs['experiment']
-        else:
-            exp = 'AUGD'
-        if 'ed' in kwargs.keys():
-            ed = kwargs['ed']
-        elif 'edition' in kwargs.keys():
-            ed = kwargs['edition']
-        else:
-            ed = 0
+        exp = parse_kwargs.parse_kw( ('exp', 'experiment'), kwargs, default='AUGD')
+        ed  = parse_kwargs.parse_kw( ('ed', 'edition'), kwargs, default=0)
 
         self.sfile, self.ed = manage_ed.sf_path(nshot, diag, exp=exp, ed=ed)
         if self.sfile is not None:
